@@ -17,7 +17,7 @@ class MeFilter(Filter):
         my_addresses = set()
         my_addresses.add(notmuch_settings.get('user', 'primary_email'))
         if notmuch_settings.has_option('user', 'other_email'):
-            for other_email in notmuch_settings.get('user', 'other_email').split(';'):
+            for other_email in notmuch_settings.get_list('user', 'other_email'):
                 my_addresses.add(other_email)
 
         self.query = ' OR '.join('to:"%s"' % address
